@@ -312,7 +312,7 @@ class ItemMapperV2 extends NewsMapperV2
     /**
      * @param string $userId
      * @param int    $feedId
-     * @param int    $updatedSince
+     * @param float  $updatedSince
      * @param bool   $hideRead
      *
      * @return Item[]
@@ -320,7 +320,7 @@ class ItemMapperV2 extends NewsMapperV2
     public function findAllInFeedAfter(
         string $userId,
         int $feedId,
-        int $updatedSince,
+        float $updatedSince,
         bool $hideRead
     ): array {
         $builder = $this->db->getQueryBuilder();
@@ -333,7 +333,7 @@ class ItemMapperV2 extends NewsMapperV2
             ->andWhere('feeds.id = :feedId')
             ->andWhere('feeds.deleted_at = 0')
             ->setParameters([
-                'updatedSince' => $updatedSince,
+                'updatedSince' => number_format($updatedSince, 0, '.', ''),
                 'feedId' => $feedId,
                 'userId'=> $userId,
             ])
@@ -351,7 +351,7 @@ class ItemMapperV2 extends NewsMapperV2
     /**
      * @param string   $userId
      * @param int|null $folderId
-     * @param int      $updatedSince
+     * @param float    $updatedSince
      * @param bool     $hideRead
      *
      * @return Item[]
@@ -359,7 +359,7 @@ class ItemMapperV2 extends NewsMapperV2
     public function findAllInFolderAfter(
         string $userId,
         ?int $folderId,
-        int $updatedSince,
+        float $updatedSince,
         bool $hideRead
     ): array {
         $builder = $this->db->getQueryBuilder();
@@ -372,7 +372,11 @@ class ItemMapperV2 extends NewsMapperV2
             ->andWhere('feeds.user_id = :userId')
             ->andWhere('feeds.deleted_at = 0')
             ->andWhere('folders.id = :folderId')
-            ->setParameters(['updatedSince' => $updatedSince, 'folderId' => $folderId, 'userId' => $userId])
+            ->setParameters([
+                'updatedSince' => number_format($updatedSince, 0, '.', ''),
+                'folderId' => $folderId,
+                'userId' => $userId,
+            ])
             ->orderBy('items.last_modified', 'DESC')
             ->addOrderBy('items.id', 'DESC');
 
@@ -386,13 +390,13 @@ class ItemMapperV2 extends NewsMapperV2
 
     /**
      * @param string $userId
-     * @param int    $updatedSince
+     * @param float  $updatedSince
      * @param int    $feedType
      *
      * @return Item[]|Entity[]
      * @throws ServiceValidationException
      */
-    public function findAllAfter(string $userId, int $feedType, int $updatedSince): array
+    public function findAllAfter(string $userId, int $feedType, float $updatedSince): array
     {
         $builder = $this->db->getQueryBuilder();
 
@@ -402,7 +406,10 @@ class ItemMapperV2 extends NewsMapperV2
             ->andWhere('items.last_modified >= :updatedSince')
             ->andWhere('feeds.deleted_at = 0')
             ->andWhere('feeds.user_id = :userId')
-            ->setParameters(['updatedSince' => $updatedSince, 'userId' => $userId])
+            ->setParameters([
+                'updatedSince' => number_format($updatedSince, 0, '.', ''),
+                'userId' => $userId,
+            ])
             ->orderBy('items.last_modified', 'DESC')
             ->addOrderBy('items.id', 'DESC');
 
